:github_url:

.. _wineenv:

.. index::
	single: Python version
	module: wenv.PythonVersion

Python Versions
===============

``wenv`` allows to handle Python versions for configuration purposes.

.. autofunction:: wenv.get_available_python_builds

.. autofunction:: wenv.get_latest_python_build

.. autoclass:: wenv.PythonVersion
    :members:
